@@ -7,9 +7,41 @@ library(yaml)
 .kmapgreybackground_file_type <- "map_grey"
 
 # utility functions for CCRI ----------------------------------------------
+
+.is_packed_rast <- function(x) {
+  if (tolower(class(x)) == "packedspatraster") {
+    TRUE
+  } else {
+    FALSE
+  }
+}
+.unpack_rast_ifnot <- function(x) {
+  if (.is_packed_rast(x)) {
+    terra::unwrap(x)
+  } else {
+    x
+  }
+}
+
+.stopifnot_sprast <- function(x) {
+  stopifnot("Require argument of type SpatRaster" = methods::isClass(x, "SpatRaster"))
+}
+
+.host_map <- function(...) {
+  if (length(...) == 1) {
+    return(...[[1]])
+  }
+  # assumes only 2 elements, since only 2 agg methods are supported,
+  # i.e. sum and mean. Take mean if both are present, else take whatever.
+  sum(...[[1]], ...[[2]], na.rm = TRUE) / 2
+}
+
 # Meta-programming approach with eval_tidy
 .cal_dist <- function(latilongimatr, method) {
 
+  #---- use Geosphere package, fun distVincentyEllipsoid() is used to calculate the distance, default distance is meter
+  # reference of standard distance in meter for one degree
+
   method <- tolower(method)
   supported <- dist_methods()
   stopifnot("Distance strategy not supported. See dist_methods()\n" = method %in% supported)
@@ -31,22 +63,44 @@ library(yaml)
   return(temp_matrix)
 }
 
-.flatten_ri <- function(isglobal, ri) {
+#' Get risk indices
+#'
+#' @description Get risk indices from GeoRasters object.
+#' @param ri GeoRasters object
+#' @return List of risk indices. If the `ri` is global, the list will contain two elements,
+#' one for each hemisphere. e.g. `list(east = list(), west = list())`. If the `ri` is not global,
+#' the list will contain a single element, e.g. `list()`.
+#' @details
+#' This function will unpack SpatRasters from GeoMadel and thus is [future::future()] safe.
+#'
+#' @export
+risk_indices <- function(ri) {
+  stopifnot("Object is not of type GeoRasters" = class(ri) == "GeoRasters")
   .ew_split <- function() {
     ew_indices <- list(list(), list())
     names(ew_indices) <- c(STR_EAST, STR_WEST)
-    for (indices in ri) {
-      ew_indices[[STR_EAST]] <- c(ew_indices[[STR_EAST]], indices[[STR_EAST]])
-      ew_indices[[STR_WEST]] <- c(ew_indices[[STR_WEST]], indices[[STR_WEST]])
+
+    for (grast in ri$global_rast) {
+      for (mod in grast$east) {
+        ew_indices[[STR_EAST]] <- c(ew_indices[[STR_EAST]], terra::rast(mod$index))
+      }
+      for (mod in grast$west) {
+        ew_indices[[STR_WEST]] <- c(ew_indices[[STR_WEST]], terra::rast(mod$index))
+      }
     }
     return(ew_indices)
   }
 
-  if (isglobal) {
+  if (ri$global) {
     #east-west split
     .ew_split()
   } else {
-    unlist(ri, recursive = FALSE)
+    unlist(lapply(
+      ri$rasters,
+      FUN = function(x) {
+        terra::rast(x$index)
+      }
+    ), recursive = FALSE)
   }
 }
 
@@ -54,6 +108,12 @@ library(yaml)
   return(terra::ext(geoscale))
 }
 
+.showmsg <- function(...) {
+  if (getOption("verbose")) {
+    message(...)
+  }
+}
+
 .valid_vector_input <- function(vector_to_check) {
   if (!is.vector(vector_to_check) || length(vector_to_check) == 0) {
     return(FALSE)
@@ -85,7 +145,11 @@ library(yaml)
 
 .download <- function(uri) {
   f <- paste(tempfile(), ".tif", sep = "")
-  stopifnot("dowload failed " = utils::download.file(uri, destfile = f, method = "auto", mode = "wb") == 0)
+  stopifnot("download failed " = utils::download.file(uri,
+                                                      destfile = f,
+                                                      method = "auto",
+                                                      mode = "wb",
+                                                      quiet = getOption("verbose")) == 0)
   return(f)
 }
 
@@ -100,6 +164,7 @@ library(yaml)
   return(terra::aggregate(rast,
                           fact = reso,
                           fun = method,
+                          na.rm = TRUE,
                           na.action = stats::na.omit))
 }
 
@@ -111,15 +176,14 @@ library(yaml)
 
   .utilrast <<- memoise::memoise(.utilrast)
   .cal_mgb <<- memoise::memoise(.cal_mgb)
-  .apply_agg <<- memoise::memoise(.apply_agg)
+  #.apply_agg <<- memoise::memoise(.apply_agg)
 }
 
 .get_helper_filepath <- function(file_type) {
   file_path <- if (file_type == "parameters") {
-     system.file("parameters.yaml",
-      package = "geohabnet",
-      mustWork = TRUE
-    )
+    system.file("parameters.yaml",
+                package = "geohabnet",
+                mustWork = TRUE)
   } else {
     .utilrast(file_type)
   }
@@ -251,16 +315,21 @@ library(yaml)
     }
   )
 
-  message("YAML object successfully written to file:", file_path)
+  .showmsg("YAML object successfully written to file: ", file_path)
 }
 
 .get_cropharvest_raster_helper <- function(crop_name, data_source) {
   if (data_source == "monfreda") {
     geodata::crop_monfreda(crop = crop_name, path = tempdir(), var = "area_f")
-  } else if (data_source == "mapspam") {
-    sp_rast(crp = crop_name) / 10000
+  } else if (data_source %in% c("mapspam2010", "mapspam2017Africa")) {
+    x <- if (data_source == "mapspam2010") {
+      sp_rast(crp = crop_name)
+    } else {
+      sp_rast(crp = crop_name, africa = TRUE)
+    }
+    x * 0.0001
   } else {
-    stop(paste("Encountered unsupported source: ", data_source))
+    stop(paste("unsupported source: ", data_source))
   }
 }
 
@@ -273,9 +342,23 @@ library(yaml)
 #' @export
 #' @examples
 #' # Get currently supported sources
-#' get_supported_sources()
-get_supported_sources <- function() {
-  return(c("monfreda", "mapspam"))
+#' supported_sources()
+supported_sources <- function() {
+  return(c(monfreda(), mapspam()))
+}
+
+#' Supported sources for monfreda
+#' 
+#' @export
+monfreda <- function() {
+  return(c("monfreda"))
+}
+
+#' Supported sources for Mapspam
+#' 
+#' @export
+mapspam <- function() {
+  return(c("mapspam2010", "mapspam2017Africa"))
 }
 
 #' Search for crop
@@ -292,7 +375,7 @@ get_supported_sources <- function() {
 #' search_crop("jackfruit")
 #' }
 #'
-#' @seealso [get_supported_sources()]
+#' @seealso [supported_sources()]
 search_crop <- function(name) {
   crp <- tolower(trimws(name))
 
